@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/ports/mozilla-firefox-1.5.0.5/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 40 "/usr/obj/ports/mozilla-firefox-1.5.0.7/mozilla/toolkit/content/contentAreaUtils.js"
 
 
 /**
@@ -66,33 +66,35 @@ function openNewWindowWith(href, sourceURL, postData)
 }
 
 /**
- * urlSecurityCheck: JavaScript wrapper for CheckLoadURI.
+ * urlSecurityCheck: JavaScript wrapper for CheckLoadURIStr.
  * If |sourceURL| is not allowed to link to |url|, this function throws with an error message.
  *
  * @param url The URL a page has linked to.
  * @param sourceURL The URL of the document from which the URL came.
+ * @param flags Flags to be passed to checkLoadURIStr. If undefined,
+ *              nsIScriptSecurityManager.STANDARD will be passed to checkLoadURIStr.
  */
-function urlSecurityCheck(url, sourceURL)
+function urlSecurityCheck(url, sourceURL, flags)
 {
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
+  if (flags === undefined)
+    flags = nsIScriptSecurityManager.STANDARD;
+
   try {
-    secMan.checkLoadURIStr(sourceURL, url, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(sourceURL, url, flags);
   } catch (e) {
     throw "Load of " + url + " from " + sourceURL + " denied.";
   }
 }
 
 function webPanelSecurityCheck(aSourceURL, aDestURL) {
-  var sourceURI = makeURI(aSourceURL);
-  var destURI = makeURI(aDestURL);
-
   const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
   var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                          .getService(nsIScriptSecurityManager);
   try {
-    secMan.checkLoadURI(sourceURI, destURI, nsIScriptSecurityManager.STANDARD);
+    secMan.checkLoadURIStr(aSourceURL, aDestURL, nsIScriptSecurityManager.STANDARD);
   } catch (e) {
     return false;
   }
@@ -457,9 +459,9 @@ function getTargetFile(aFpP, aSkipPrompt)
     if (aFolderType != "Downloads")
       throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
     
-//@line 504 "/usr/obj/ports/mozilla-firefox-1.5.0.5/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 506 "/usr/obj/ports/mozilla-firefox-1.5.0.7/mozilla/toolkit/content/contentAreaUtils.js"
     return "Home";
-//@line 507 "/usr/obj/ports/mozilla-firefox-1.5.0.5/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 509 "/usr/obj/ports/mozilla-firefox-1.5.0.7/mozilla/toolkit/content/contentAreaUtils.js"
   }
   
   function getDownloadsFolder(aFolder)
@@ -847,7 +849,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 898 "/usr/obj/ports/mozilla-firefox-1.5.0.5/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 900 "/usr/obj/ports/mozilla-firefox-1.5.0.7/mozilla/toolkit/content/contentAreaUtils.js"
       
   // Fix up the file name we're saving to to include the default extension
   var i = aFile.lastIndexOf(".");
